Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(220)

Unified Diff: vm/flow_graph_builder.h

Issue 10632009: Make the parser agnostic to the TokenStream implementation. This is the first step towards compacti… (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/runtime/
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « vm/debugger.cc ('k') | vm/flow_graph_builder.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: vm/flow_graph_builder.h
===================================================================
--- vm/flow_graph_builder.h (revision 9042)
+++ vm/flow_graph_builder.h (working copy)
@@ -137,7 +137,7 @@
// allocation call.
// May be called only if allocating an object of a parameterized class.
BindInstr* BuildInstantiatedTypeArguments(
- intptr_t token_index,
+ intptr_t token_pos,
const AbstractTypeArguments& type_arguments);
// Creates a possibly uninstantiated type argument vector and the type
@@ -147,21 +147,21 @@
void BuildConstructorTypeArguments(ConstructorCallNode* node,
ZoneGrowableArray<Value*>* args);
- void BuildTypecheckArguments(intptr_t token_index,
+ void BuildTypecheckArguments(intptr_t token_pos,
Value** instantiator,
Value** instantiator_type_arguments);
Value* BuildInstantiator();
- Value* BuildInstantiatorTypeArguments(intptr_t token_index,
+ Value* BuildInstantiatorTypeArguments(intptr_t token_pos,
Value* instantiator);
// Perform a type check on the given value.
- AssertAssignableComp* BuildAssertAssignable(intptr_t token_index,
+ AssertAssignableComp* BuildAssertAssignable(intptr_t token_pos,
Value* value,
const AbstractType& dst_type,
const String& dst_name);
// Perform a type check on the given value and return it.
- Value* BuildAssignableValue(intptr_t token_index,
+ Value* BuildAssignableValue(intptr_t token_pos,
Value* value,
const AbstractType& dst_type,
const String& dst_name);
@@ -289,17 +289,17 @@
// We expect that AstNode in test contexts either have only nonlocal exits
// or else control flow has both true and false successors.
//
// The cis and token_index are used in checked mode to verify that the
// condition of the test is of type bool.
class TestGraphVisitor : public ValueGraphVisitor {
public:
TestGraphVisitor(FlowGraphBuilder* owner,
intptr_t temp_index,
- intptr_t condition_token_index)
+ intptr_t condition_token_pos)
: ValueGraphVisitor(owner, temp_index),
true_successor_address_(NULL),
false_successor_address_(NULL),
- condition_token_index_(condition_token_index) {
+ condition_token_pos_(condition_token_pos) {
}
TargetEntryInstr** true_successor_address() const {
@@ -311,7 +311,7 @@
return false_successor_address_;
}
- intptr_t condition_token_index() const { return condition_token_index_; }
+ intptr_t condition_token_pos() const { return condition_token_pos_; }
private:
// Construct and concatenate a Branch instruction to this graph fragment.
@@ -322,7 +322,7 @@
TargetEntryInstr** true_successor_address_;
TargetEntryInstr** false_successor_address_;
- intptr_t condition_token_index_;
+ intptr_t condition_token_pos_;
};
} // namespace dart
« no previous file with comments | « vm/debugger.cc ('k') | vm/flow_graph_builder.cc » ('j') | no next file with comments »
@@ -289,17 +289,17 @@
// or else control flow has both true and false successors.
//
-// The cis and token_index are used in checked mode to verify that the
+// The cis and token_pos are used in checked mode to verify that the
// condition of the test is of type bool.
class TestGraphVisitor : public ValueGraphVisitor {

Powered by Google App Engine
This is Rietveld 408576698